==> crow-2.11.0.tar.bz2: crow-2.11.0/crow/views2.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef CROW_VIEWS2_H
#define CROW_VIEWS2_H

#include "views1.h"

namespace Crow {

class GtkWindowView : public GtkBinView {

public:
	using GlibObjectView::getObject;

	GtkWindowView();

protected:
	virtual Gtk::Widget * createDesignWindow();
	Any createInstance();
	void initDesign();

};

class DialogButtonEntry : public Glib::Object {

public:
	DialogButtonEntry();

	PGtkWidget widget;
	Gtk::ResponseType response;
	bool secondary;
	
};

typedef Glib::RefPtr<DialogButtonEntry> PDialogButtonEntry;

class DialogButtonEntryView : public TCreateInstance<DialogButtonEntry> {

public:
	DialogButtonEntryView();

protected:
	Any getWidget(Property * property);
	void setWidget(Property * property, Any value);
	Any getResponse(Property * property);
	void setResponse(Property * property, Any value);
	Any getSecondary(Property * property);
	void setSecondary(Property * property, Any value);

};

class GtkDialogView : public GtkWindowView {

public:
	GtkDialogView();

protected:
	BinContainer * createContainer();
	Gtk::Widget * createDesignWindow();

	void setButtons(Property * property, Any value);
	void clearButtons();
	void addButton(PDialogButtonEntry entry);

	std::string getButtonLabel(Property * property, PNode node);

};

class GtkDialogViewFinal : public GtkDialogView {

public:
	GtkDialogViewFinal();
	
protected:
	void initDesign() { }

};

class GtkColorSelectionDialogView : public GtkDialogViewFinal {

public:
	GtkColorSelectionDialogView();

protected:
	Gtk::Widget * createDesignWindow();

	Any getColorsel(Property * property);

};

class GtkFileFilterView : public GlibObjectView {

public:
	GtkFileFilterView();

protected:
	Any createInstance();
	Any getName(Property * property);
	void setName(Property * property, Any value);

};

class GtkFileChooserViewBase : public virtual GtkWidgetView {

public:
	GtkFileChooserViewBase();

	virtual Glib::RefPtr<Gtk::FileChooser> getObject();

protected:
	void setFilters(Property * property, Any value);
	void setFilter(Property * property, Any value);
	void clearFilters();

	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkFileChooserDialogView : public GtkDialogViewFinal, public GtkFileChooserViewBase {

public:
	GtkFileChooserDialogView();

	Glib::RefPtr<Gtk::FileChooser> getObject();
	
protected:
	Gtk::Widget * createDesignWindow();

};

class GtkFontSelectionDialogView : public GtkDialogViewFinal {

public:
	GtkFontSelectionDialogView();
	
protected:
	Gtk::Widget * createDesignWindow();

	Any getFontSelection(Property * property);

};

class GtkStatusbarView : public GtkContainerViewBase, public TCreateInstance<Gtk::Statusbar> {

public:
	GtkStatusbarView();

};

class TooltipsEntry : public Glib::Object {

public:
	TooltipsEntry();

	PGtkWidget widget;
	Glib::ustring tip_text;
	Glib::ustring tip_private;

};

typedef Glib::RefPtr<TooltipsEntry> PTooltipsEntry;

class TooltipsEntryView : public TCreateInstance<TooltipsEntry> {

public:
	TooltipsEntryView();

protected:
	Any getWidget(Property * property);
	void setWidget(Property * property, Any value);
	Any getTipText(Property * property);
	void setTipText(Property * property, Any value);
	Any getTipPrivate(Property * property);
	void setTipPrivate(Property * property, Any value);

};

class GtkTooltipsView : public TCreateInstance<Gtk::Tooltips> {

public:
	GtkTooltipsView();

protected:
	std::string getTipLabel(Property * property, PNode node);

};

class GtkActionGroupView : public GlibObjectView {

public:
	GtkActionGroupView();

protected:
	Any createInstance();
	void doneInstance();
	void setActions(Property * property, Any value);
	void clearActions();
	std::string getActionLabel(Property * property, PNode node);

};

class GtkActionView : public GlibObjectView {

public:
	GtkActionView();

protected:
	Any createInstance();
	void setLabel(Property * property, Any value);
	void setStockId(Property * property, Any value);

};

class GtkToggleActionView : public GtkActionView {

public:
	GtkToggleActionView();

protected:
	Any createInstance();

};

class GtkRadioActionView : public GtkToggleActionView {

public:
	GtkRadioActionView();

protected:
	Any createInstance();
	void setActive(Property * property, Any value);

private:
	Glib::RefPtr<Gtk::RadioAction> dummy;

};

class GtkUIManagerView : public GlibObjectView {

public:
	GtkUIManagerView();

	Gtk::UIManager::ui_merge_id getMergeId(int index);

protected:
	Any createInstance();
	void setActionGroups(Property * property, Any value);

private:
	typedef std::vector<Gtk::UIManager::ui_merge_id> MergeIds;
	MergeIds mergeIds;

};

class UIDefinition : public Glib::Object {

public:
	UIDefinition();
	Glib::PropertyProxy<Glib::ustring> property_ui() { return propertyUi.get_proxy(); }

private:
	Glib::Property<Glib::ustring> propertyUi;

};

class UIDefinitionView : public TCreateInstance<UIDefinition> {

public:
	UIDefinitionView();

};

class UIElementView : public GtkContainerViewBase {

public:
	UIElementView();

protected:
	Any createInstance();
	virtual bool validWidget(Gtk::Widget * widget) = 0;
	virtual PGtkWidget createStub() = 0;

};

class GtkMenuBarView : public UIElementView {

public:
	using GlibObjectView::getObject;

	GtkMenuBarView();

protected:
	bool validWidget(Gtk::Widget * widget);
	PGtkWidget createStub();

};

class GtkToolbarView : public UIElementView {

public:
	using GlibObjectView::getObject;

	GtkToolbarView();

protected:
	bool validWidget(Gtk::Widget * widget);
	PGtkWidget createStub();
	void setToolbarStyleSet(Property * property, Any value);
	Any getTooltips(Property * property);
	void setTooltips(Property * property, Any value);
	void setIconSizeSet(Property * property, Any value);

};

class RadioGroup : public Glib::Object {

public:
	RadioGroup();
	Gtk::RadioButtonGroup * getGroup() { return &group; }

private:
	Gtk::RadioButtonGroup group;

};

class RadioGroupView : public TCreateInstance<RadioGroup> {
};

class GtkMiscView : public GtkWidgetView {

public:
	GtkMiscView();

};

class GtkLabelView : public GtkMiscView, public TCreateInstance<Gtk::Label> {

public:
	using TCreateInstance<Gtk::Label>::getObject;

	GtkLabelView();

protected:
	void initDesign();

};

class GtkButtonViewBase : public virtual GtkWidgetView {

public:
	GtkButtonViewBase();

};

class GtkButtonView : public GtkBinView, public GtkButtonViewBase, public TCreateInstance<Gtk::Button> {

public:
	using TCreateInstance<Gtk::Button>::getObject;

	GtkButtonView();

protected:
	enum ButtonState { bsNormal, bsStock, bsContainer };

	void initDesign();
	void setupContainer();
	void onAsContainerSetup();
	void resetButton();
	void setState(ButtonState bs);
	void setStockId(Property * property, Any value);
	void setImage(Property * property, Any value);

	void setImageWidget(Gtk::Widget * widget);

	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkToggleButtonView : public GtkButtonView {

public:
	GtkToggleButtonView();

protected:
	Any createInstance();

};

class GtkCheckButtonView : public GtkToggleButtonView {

public:
	GtkCheckButtonView();

protected:
	Any createInstance();

};

class GtkRadioButtonView : public GtkCheckButtonView {

public:
	using GlibObjectView::getObject;

	GtkRadioButtonView();

protected:
	Any createInstance();
	void setActive(Property * property, Any value);

private:
	Glib::RefPtr<Gtk::RadioButton> dummy;

};

}

#endif

==> crow-2.11.3.tar.bz2: crow-2.11.3/crow/views2.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2008 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_VIEWS2_H
#define CROW_VIEWS2_H

#include "views1.h"

namespace Crow {

class GtkWindowView : public GtkBinView {

public:
	using GlibObjectView::getObject;

	GtkWindowView();

protected:
	virtual Gtk::Widget * createDesignWindow();
	Any createInstance();
	void initDesign();

};

class DialogButtonEntry : public Glib::Object {

public:
	DialogButtonEntry();

	PGtkWidget widget;
	Gtk::ResponseType response;
	bool secondary;
	
};

typedef Glib::RefPtr<DialogButtonEntry> PDialogButtonEntry;

class DialogButtonEntryView : public TCreateInstance<DialogButtonEntry> {

public:
	DialogButtonEntryView();

protected:
	Any getWidget(Property * property);
	void setWidget(Property * property, Any value);
	Any getResponse(Property * property);
	void setResponse(Property * property, Any value);
	Any getSecondary(Property * property);
	void setSecondary(Property * property, Any value);

};

class GtkDialogView : public GtkWindowView {

public:
	GtkDialogView();

protected:
	BinContainer * createContainer();
	Gtk::Widget * createDesignWindow();

	void setButtons(Property * property, Any value);
	void clearButtons();
	void addButton(PDialogButtonEntry entry);

	std::string getButtonLabel(Property * property, PNode node);

};

class GtkDialogViewFinal : public GtkDialogView {

public:
	GtkDialogViewFinal();
	
protected:
	void initDesign() { }

};

class GtkColorSelectionDialogView : public GtkDialogViewFinal {

public:
	GtkColorSelectionDialogView();

protected:
	Gtk::Widget * createDesignWindow();

	Any getColorsel(Property * property);

};

class GtkFileFilterView : public GlibObjectView {

public:
	GtkFileFilterView();

protected:
	Any createInstance();
	Any getName(Property * property);
	void setName(Property * property, Any value);

};

class GtkFileChooserViewBase : public virtual GtkWidgetView {

public:
	GtkFileChooserViewBase();

	virtual Glib::RefPtr<Gtk::FileChooser> getObject();

protected:
	void initInstance();
	void initFileChooserInstance();
	
	void setFilters(Property * property, Any value);
	void setFilter(Property * property, Any value);
	void clearFilters();

	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkFileChooserDialogView : public GtkDialogViewFinal, public GtkFileChooserViewBase {

public:
	GtkFileChooserDialogView();

	Glib::RefPtr<Gtk::FileChooser> getObject();
	
protected:
	Gtk::Widget * createDesignWindow();
	void initInstance();
	
};

class GtkFontSelectionDialogView : public GtkDialogViewFinal {

public:
	GtkFontSelectionDialogView();
	
protected:
	Gtk::Widget * createDesignWindow();

	Any getFontSelection(Property * property);

};

class GtkStatusbarView : public GtkContainerViewBase, public TCreateInstance<Gtk::Statusbar> {

public:
	GtkStatusbarView();

};

class GtkActionGroupView : public GlibObjectView {

public:
	GtkActionGroupView();

protected:
	Any createInstance();
	void doneInstance();
	void setActions(Property * property, Any value);
	void clearActions();
	std::string getActionLabel(Property * property, PNode node);

};

class GtkActionView : public virtual GlibObjectView {

public:
	GtkActionView();

protected:
	Any createInstance();
	Glib::ustring createName();
	void setLabel(Property * property, Any value);
	void setStockId(Property * property, Any value);

};

class GtkToggleActionView : public GtkActionView {

public:
	GtkToggleActionView();

protected:
	Any createInstance();

};

class GtkRadioActionView : public GtkToggleActionView {

public:
	GtkRadioActionView();

protected:
	Any createInstance();
	void setActive(Property * property, Any value);

private:
	Glib::RefPtr<Gtk::RadioAction> dummy;

};

class GtkUIManagerView : public GlibObjectView {

public:
	GtkUIManagerView();

	Gtk::UIManager::ui_merge_id getMergeId(int index);

protected:
	Any createInstance();
	void setActionGroups(Property * property, Any value);

private:
	typedef std::vector<Gtk::UIManager::ui_merge_id> MergeIds;
	MergeIds mergeIds;

};

class UIDefinition : public Glib::Object {

public:
	UIDefinition();
	Glib::PropertyProxy<Glib::ustring> property_ui() { return propertyUi.get_proxy(); }

private:
	Glib::Property<Glib::ustring> propertyUi;

};

class UIDefinitionView : public TCreateInstance<UIDefinition> {

public:
	UIDefinitionView();

};

class UIElementView : public GtkContainerViewBase {

public:
	UIElementView();

protected:
	Any createInstance();
	virtual bool validWidget(Gtk::Widget * widget) = 0;
	virtual PGtkWidget createStub() = 0;

};

class GtkMenuBarView : public UIElementView {

public:
	using GlibObjectView::getObject;

	GtkMenuBarView();

protected:
	bool validWidget(Gtk::Widget * widget);
	PGtkWidget createStub();

};

class GtkToolbarView : public UIElementView {

public:
	using GlibObjectView::getObject;

	GtkToolbarView();

protected:
	bool validWidget(Gtk::Widget * widget);
	PGtkWidget createStub();
	void setToolbarStyleSet(Property * property, Any value);
	Any getTooltips(Property * property);
	void setTooltips(Property * property, Any value);
	void setIconSizeSet(Property * property, Any value);

};

class RadioGroup : public Glib::Object {

public:
	RadioGroup();
	Gtk::RadioButtonGroup * getGroup() { return &group; }

private:
	Gtk::RadioButtonGroup group;

};

class RadioGroupView : public TCreateInstance<RadioGroup> {
};

class GtkMiscView : public GtkWidgetView {

public:
	GtkMiscView();

};

class GtkLabelView : public GtkMiscView, public TCreateInstance<Gtk::Label> {

public:
	using TCreateInstance<Gtk::Label>::getObject;

	GtkLabelView();

protected:
	void initDesign();

};

class GtkButtonViewBase : public virtual GtkWidgetView {

public:
	GtkButtonViewBase();

};

class GtkButtonView : public GtkBinView, public GtkButtonViewBase, public TCreateInstance<Gtk::Button> {

public:
	using TCreateInstance<Gtk::Button>::getObject;

	GtkButtonView();

protected:
	enum ButtonState { bsNormal, bsStock, bsContainer };

	void initDesign();
	void setupContainer();
	void onAsContainerSetup();
	void resetButton();
	void setState(ButtonState bs);
	void setStockId(Property * property, Any value);
	void setImage(Property * property, Any value);

	void setImageWidget(Gtk::Widget * widget);

	bool isActiveWidget(Gtk::Widget * widget);

};

class GtkToggleButtonView : public GtkButtonView {

public:
	GtkToggleButtonView();

protected:
	Any createInstance();

};

class GtkCheckButtonView : public GtkToggleButtonView {

public:
	GtkCheckButtonView();

protected:
	Any createInstance();

};

class GtkRadioButtonView : public GtkCheckButtonView {

public:
	using GlibObjectView::getObject;

	GtkRadioButtonView();

protected:
	Any createInstance();
	void setActive(Property * property, Any value);

private:
	Glib::RefPtr<Gtk::RadioButton> dummy;

};

class GtkScaleButtonView : public GtkContainerViewBase, public GtkButtonViewBase {

public:
	GtkScaleButtonView();

protected:
	Any createInstance();
	void setIcons(Property * property, Any value);

};

}

#endif
